#!/usr/bin/env bash

# TODO: check required tools
REQUIRED_TOOLS=(jq xpath)
MISSING_TOOLS=""

for tool in "${REQUIRED_TOOLS[@]}" ; do
    [[ -z "$(which $tool)" ]] && MISSING_TOOLS="$MISSING_TOOLS $tool"
done
if [[ -n "${MISSING_TOOLS}" ]] ; then
    printf "[-] You are missing the following tools: %s\n" "${MISSING_TOOLS}"
    exit 1
fi

# first item is 'start' rather than latest tag for pressflow/7
NEW_VERSION_7=$(curl https://api.github.com/repos/pressflow/7/tags 2>/dev/null | jq -r .[1].name)
NEW_VERSION_7_CIVI=$(curl https://api.github.com/repos/civicrm/civicrm-core/tags 2>/dev/null | jq -r .[0].name)
NEW_VERSION_9=$(curl https://git.drupalcode.org/project/drupal/-/tags?format=atom 2>/dev/null \
    | xpath -e '//entry/title/text()' 2> /dev/null| grep --color=never '^9' | sort -r | head -1)

CURRENT_VERSION_7=$(grep 'projects\[drupal\]\[download\]\[tag\]' includes/7/core.make | sed -e 's/.* = \(.*\)$/\1/')
CURRENT_VERSION_7_CIVI=$(grep 'libraries\[civicrm\]\[download\]\[url\]' includes/7/civicrm/civicrm-50.make \
    | sed -e 's/^.*civicrm-\(.*\)-drupal.*$/\1/')
CURRENT_VERSION_9=$(cat includes/9/composer.json | jq .require | jq -r '.["drupal/core-recommended"]')

printf "[+] Drupal update !\n"
printf "[+] platform\tcurrent\t\tlatest\n"
printf "[+] --------\t-------\t\t------\n"
printf "[+] DRUPAL7\t%s\t%s\n" "${CURRENT_VERSION_7}" "${NEW_VERSION_7}"
printf "[+] D7_CIVI\t%s\t\t%s\n" "${CURRENT_VERSION_7_CIVI}" "${NEW_VERSION_7_CIVI}"
printf "[+] DRUPAL9\t%s\t\t%s\n" "${CURRENT_VERSION_9}" "${NEW_VERSION_9}"

TEMPLATES=("7-core.make" "civicrm-50.make" "9-compose.json")
END_FILES=("7/core.make" "7/civicrm/civicrm-50.make" "9/composer.json")
VAR_NAME=('\${DRUPAL7}' '\${D7_CIVI}' '\${DRUPAL9}')
VERSIONS=("${NEW_VERSION_7}" "${NEW_VERSION_7_CIVI}" "${NEW_VERSION_9}")

git pull

for i in "${!TEMPLATES[@]}" ; do
    sed -e "s/${VAR_NAME[$i]}/${VERSIONS[$i]}/" "templates/${TEMPLATES[$i]}" > "includes/${END_FILES[$i]}"
done
